# Table of Contents

- [application-modernization](<./application-modernization.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Application Modernization](<./Application-Modernization.md>)
  - [Overview](<./Application-Modernization/Overview.md>)
  - [What Is Application Modernization?](<./Application-Modernization/What-Is-Application-Modernization.md>)
  - [Why Is Application Modernization Relevant?](<./Application-Modernization/Why-Is-Application-Modernization-Relevant.md>)
  - [Before You Start](<./Application-Modernization/Before-You-Start.md>)
  - [Step-by-Step Guide](<./Application-Modernization/Step-by-Step-Guide.md>)
